#[repr(u8)]pub enum ValidationConclusion {
ValidationConclusionUnspecified = 0,
ValidatedVersionUsed = 1,
UserVersionUsed = 2,
UnvalidatedVersionUsed = 3,
Unused = 4,
}Expand description
The possible final outcomes of the sequence of address validation requests needed to validate an address.
Variants
ValidationConclusionUnspecified = 0
This value is unused. If the
ProvideValidationFeedbackRequest.conclusion field is set to
VALIDATION_CONCLUSION_UNSPECIFIED, an INVALID_ARGUMENT error will be
returned.
ValidatedVersionUsed = 1
The version of the address returned by the Address Validation API was used for the transaction.
UserVersionUsed = 2
The version of the address provided by the user was used for the transaction
UnvalidatedVersionUsed = 3
A version of the address that was entered after the last validation attempt but that was not re-validated was used for the transaction.
Unused = 4
The transaction was abandoned and the address was not used.