pub struct TransitTime {
pub text: String,
pub time_zone: Tz,
pub value: NaiveDateTime,
}Expand description
A representation of time as a Date object, a localized string, and a time zone.
Fields
text: StringA string representing the time’s value. The time is displayed in the time zone of the transit stop.
time_zone: TzThe time zone in which this stop lies. The value is the name of the time
zone as defined in the IANA Time Zone
Database, e.g. “America/New_York”.
value: NaiveDateTimeThe time of this departure or arrival.