pub enum Status {
InvalidRequest,
MaxElementsExceeded,
MaxDimensionsExceeded,
Ok,
OverDailyLimit,
OverQueryLimit,
RequestDenied,
UnknownError,
}Expand description
The status fields within the response object contain the status of the
request, and may contain useful debugging information. The Distance Matrix
API returns a top-level status field, with information about the request in
general, as well as a status field for each element field, with information
about that particular origin-destination pairing.
Variants
InvalidRequest
Indicates that the provided request was invalid. Common causes of this status include an invalid parameter or parameter value.
MaxElementsExceeded
Indicates that the product of origins and destinations exceeds the per-query limit.
MaxDimensionsExceeded
Indicates that the number of origins or destinations exceeds the per-query limit.
Ok
Indicates the response contains a valid result.
OverDailyLimit
Indicates any of the following:
- The API key is missing or invalid.
- Billing has not been enabled on your account.
- A self-imposed usage cap has been exceeded.
- The provided method of payment is no longer valid (for example, a credit card has expired).
See the Maps FAQ to learn how to fix this.
OverQueryLimit
Indicates the service has received too many requests from your application within the allowed time period.
RequestDenied
Indicates that the service denied use of the Distance Matrix service by your application.
UnknownError
Indicates a Distance Matrix request could not be processed due to a server error. The request may succeed if you try again.