pub struct SnappedPoint {
pub location: LatLng,
pub place_id: Option<String>,
pub origin_index: Option<usize>,
}Expand description
Fields
location: LatLngSee LatitudeLongitudeLiteral for more information.
place_id: Option<String>A unique identifier for a place. All place IDs returned by the Roads API correspond to road segments.
origin_index: Option<usize>An integer that indicates the corresponding value in the original
request. Each value in the request should map to a snapped value in the
response. However, if you’ve set interpolate=true, then it’s possible
that the response will contain more coordinates than the request.
Interpolated values will not have an originalIndex. These values are
indexed from 0, so a point with an originalIndex of 4 will be the
snapped value of the 5th latitude/longitude passed to the path
parameter.