pub enum Status {
InvalidArgument,
PermissionDenied,
NotFound,
ResourceExhausted,
}Expand description
Indicates the status of the response.
Variants
InvalidArgument
-
Your API key is not valid or was not included in the request. Please ensure that you’ve included the entire key, and that you’ve enabled the API for this key.
-
Your request contained invalid arguments. The most likely causes of this error are:
- A problem with your path parameter.
- Please ensure you have at least 1, and fewer than 100 points. Each
point should be a pair of numbers separated by a comma, such as:
48.409114,-123.369158. Points should be separated by a pipe: ‘|’. - Your request included an invalid
placeId. - Your request included both
placeIds and apath. Only one of these parameters may be specified for each request. This error will not be returned if aplaceIdis passed for a road which no longer exists, or for a place which is not a road.
PermissionDenied
The request was denied for one or more of the following reasons:
- The API key is missing or invalid.
- Billing has not been enabled on your account.
- A self-imposed usage cap has been exceeded.
- The provided method of payment is no longer valid (for example, a credit card has expired).
In order to use Google Maps Platform products, billing must be enabled on your account, and all requests must include a valid API key. To fix this, take the following steps:
- Get an API key
- Enable billing on your account.
- Adjust your usage cap to increase your daily limit (if applicable).
NotFound
Ensure that you are sending requests to https://roads.googleapis.com/
and not http://roads.googleapis.com/.
ResourceExhausted
You have exceeded the request limit that you configured in the Google Cloud Platform Console. This limit is typically set as requests per day, requests per 100 seconds, and requests per 100 seconds per user. This limit should be configured to prevent a single or small group of users from exhausting your daily quota, while still allowing reasonable access to all users. See Capping API Usage to configure these limits.