pub enum Error {
}Expand description
Errors that may be produced by the root part of the Google Maps Platform API client.
Variants
Type(Error)
Error originating from the types and structs in the google_maps crate.
AddressValidation(Error)
Error originating from the Google Maps Address Validation API client module or server.
Directions(Error)
Error originating from the Google Maps Directions API client module or server.
DistanceMatrix(Error)
Error originating from the Google Maps Distance Matrix API client module or server.
Elevation(Error)
Error originating from the Google Maps Elevation API client module or server.
Geocoding(Error)
Error originating from the Google Maps Geocoding API client module or server.
PlacesNew
Error originating from the Google Maps Places API (New) client module or server.
Roads(Error)
Error originating from the Google Maps Roads API client module or server.
TimeZone(Error)
Error originating from the Google Maps Time Zone API client module or server.
Reqwest(Error)
Error originating from the reqwest crate.
Http(HttpErrorStatus)
An HTTP status code returned by the remote server indicates an error. This represents a successful HTTP connection but an unsuccessful HTTP request or transaction with the server.
403 Forbidden· Ensure that a correct Google Maps API key is being supplied and that the target API has been enabled for this API key.
InvalidHeaderValue
Invalid HTTP header value.
Occurs when attempting to create an HTTP header with an invalid value, typically due to non-ASCII characters or other formatting issues that violate HTTP header specifications.
Json(Error)
Error originating from the serde_json crate.
Generally this means that the Google Maps API returned data in an
unexpected format. A struct or enum may need to be changed in this
crate to match what Google Maps
is returning.
Please file an issue and include as much information as possible, including the request and the JSON response if available.