Resources (enums, structs) for processing the Snap To Roads response from the Google Maps Platform. Look in here for more information about the data returned from Google’s server and how to parse it with your program.
Resources (enums, structs) for processing the Snap To Roads response from the Google Maps Platform. Look in here for more information about the data returned from Google’s server and how to parse it with your program.